[![Build Status](https://travis-ci.org/bsamseth/qflow.svg?branch=master)](https://travis-ci.org/bsamseth/qflow)
[![codecov](https://codecov.io/gh/bsamseth/qflow/branch/master/graph/badge.svg)](https://codecov.io/gh/bsamseth/qflow)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/bsamseth/qflow.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/bsamseth/qflow/context:python)
[![Language grade: C/C++](https://img.shields.io/lgtm/grade/cpp/g/bsamseth/qflow.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/bsamseth/qflow/context:cpp)
[![Total alerts](https://img.shields.io/lgtm/alerts/g/bsamseth/qflow.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/bsamseth/qflow/alerts/)
[![Lines of Code](https://tokei.rs/b1/github/bsamseth/qflow)](https://tokei.rs/b1/github/bsamseth/qflow)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

<p align="center">
  <img src="docs/logo.png" height="200px">
</p>

# QFLOW - Quantum Variational Monte Carlo with Neural Networks

See the [documentation pages](https://bsamseth.github.io/qflow) for details regarding the `qflow` package.

For the accompanying master's thesis, see [writing/Thesis.pdf](https://github.com/bsamseth/qflow/raw/master/writing/Thesis.pdf)
